#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define platform hikey960%{nil}
%define edk2_platforms_version 0.0~20230118T162833~201514e6
%define edk2_non_osi_version 0.0~20230118T154213~bc0b6bf
%define brotli_version 0.0~20220110T130810~f4153a0
%global openssl_version 1.1.1s

# Build with edk2-non-osi
%bcond_without edk2_non_osi

# Build in debug mode by default
%bcond_without edk2_debug
%if %{with edk2_debug}
%define build_mode DEBUG
%else
%define build_mode RELEASE
%endif

# This differs on RC
%define archive_version 202211

%if "%{platform}" != "%{nil}"
Name:           edk2-%{platform}
%else
Name:           edk2
%endif
Version:        0.0~20230118T162833~201514e6
Release:        3.1
Summary:        Firmware required to run the %{platform}
License:        SUSE-Firmware
Group:          System/Boot
URL:            https://github.com/tianocore/edk2
Source0:        https://github.com/tianocore/edk2/archive/edk2-stable%{archive_version}.tar.gz
Source1:        edk2-platforms-%{edk2_platforms_version}.tar.xz
Source2:        edk2-non-osi-%{edk2_non_osi_version}.tar.xz
Source3:        brotli-%{brotli_version}.tar.xz
Source10:       https://www.openssl.org/source/openssl-%{openssl_version}.tar.gz
Source11:       https://www.openssl.org/source/openssl-%{openssl_version}.tar.gz.asc
Source12:       openssl.keyring
Patch999:       edk2-platforms-fix-Hikeys.patch
#!BuildIgnore:  gcc-PIE
%if "%{platform}" != "hikey" && "%{platform}" != "hikey960"
BuildRequires:  acpica
%endif
BuildRequires:  bc
BuildRequires:  dos2unix
%if "%{platform}" == "Armada80x0McBin"
BuildRequires:  dtc
%endif
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libuuid-devel
BuildRequires:  python3
BuildRequires:  unzip
%if "%{platform}" == ""
ExclusiveArch:  do_not_build
%else
ExclusiveArch:  aarch64
%endif

%description
Firmware required to run the %{platform}

%prep
%setup -q -n edk2-edk2-stable%{archive_version} -a 1 -a 2 -a 3
pushd edk2-platforms-%{edk2_platforms_version}
%patch999 -p1
popd

# Fix path of the brotli submodules
cp -R brotli-%{brotli_version}/* BaseTools/Source/C/BrotliCompress/brotli/
cp -R brotli-%{brotli_version}/* MdeModulePkg/Library/BrotliCustomDecompressLib/brotli/

ln -sf edk2-platforms-%{edk2_platforms_version} edk2-platforms
ln -sf edk2-non-osi-%{edk2_non_osi_version} edk2-non-osi

# add openssl
pushd CryptoPkg/Library/OpensslLib/openssl
tar -xf %{SOURCE10} --strip 1
popd

%build
%if %{with edk2_non_osi}
export PACKAGES_PATH=$PWD:$PWD/edk2-platforms:$PWD/edk2-platforms/Drivers:$PWD/edk2-non-osi
%else
export PACKAGES_PATH=$PWD:$PWD/edk2-platforms:$PWD/edk2-platforms/Drivers
%endif
export PYTHON_COMMAND=python3
%if "%{platform}" == "ArmVExpress-FVP-AArch64"
DSC_PATH="edk2-platforms/Platform/ARM/VExpressPkg/ArmVExpress-FVP-AArch64.dsc"
%endif
%if "%{platform}" == "hikey"
DSC_PATH="edk2-platforms/Platform/Hisilicon/HiKey/HiKey.dsc"
%endif
%if "%{platform}" == "hikey960"
DSC_PATH="edk2-platforms/Platform/Hisilicon/HiKey960/HiKey960.dsc"
%endif
%if "%{platform}" == "Armada80x0McBin"
DSC_PATH="edk2-platforms/Platform/SolidRun/Armada80x0McBin/Armada80x0McBin.dsc"
%endif
%if "%{platform}" == "RPi3"
DSC_PATH="edk2-platforms/Platform/RaspberryPi/RPi3/RPi3.dsc"
%endif
%if "%{platform}" == "RPi4"
DSC_PATH="edk2-platforms/Platform/RaspberryPi/RPi4/RPi4.dsc"
%endif
%if "%{platform}" == "Overdrive1000Board"
DSC_PATH="edk2-platforms/Platform/SoftIron/Overdrive1000Board/Overdrive1000Board.dsc"
%endif
%if "%{platform}" == "SbsaQemu"
DSC_PATH="edk2-platforms/Platform/Qemu/SbsaQemu/SbsaQemu.dsc"
%endif
BUILD_OPTIONS="-a AARCH64 -p $DSC_PATH -b %{build_mode} -t GCC5 %{?jobs:-n %jobs}"
# BaseTools does not support parallel builds, so no -jN here
ARCH=AARCH64 make -C BaseTools BUILD_CC=gcc BUILD_CXX=g++ BUILD_AS=gcc

. ./edksetup.sh

build $BUILD_OPTIONS

%install
# default outdir
%define outdir Build/%{platform}/%{build_mode}_GCC5
%if "%{platform}" == "hikey"
%if %{with edk2_non_osi}
install -D -m 0644 edk2-non-osi/Platform/Hisilicon/HiKey/mcuimage.bin %{buildroot}/boot/mcuimage.bin
%endif
%define outdir Build/HiKey/%{build_mode}_GCC5
%define fd_file BL33_AP_UEFI.fd
%endif
%if "%{platform}" == "hikey960"
%if %{with edk2_non_osi}
install -D -m 0644 edk2-non-osi/Platform/Hisilicon/HiKey960/lpm3.img %{buildroot}/boot/lpm3.img
%endif
%define outdir Build/HiKey960/%{build_mode}_GCC5
%define fd_file BL33_AP_UEFI.fd
%endif
%if "%{platform}" == "ArmVExpress-FVP-AArch64"
%define fd_file FVP_AARCH64_EFI.fd
%endif
%if "%{platform}" == "Armada80x0McBin"
%define outdir Build/Armada80x0McBin-AARCH64/%{build_mode}_GCC5
%define fd_file ARMADA_EFI.fd
%endif
%if "%{platform}" == "Overdrive1000Board"
%define outdir Build/Overdrive1000/%{build_mode}_GCC5
%define fd_file OVERDRIVE1000_ROM.fd
%endif
%if "%{platform}" == "RPi3"
%define fd_file RPI_EFI.fd
%endif
%if "%{platform}" == "RPi4"
%define fd_file RPI_EFI.fd
%endif
%if "%{platform}" == "SbsaQemu"
%define fd_file SBSA_FLASH[01].fd
truncate -s 256M %{outdir}/FV/%{fd_file}
%endif

find %{outdir} -name *.fd

pushd %{outdir}/FV
for file in %{fd_file}; do
  install -D -m 0644 $file %{buildroot}/boot/$file
done
popd

%files
%if %{with edk2_non_osi}
%if "%{platform}" == "hikey"
/boot/mcuimage.bin
%endif
%if "%{platform}" == "hikey960"
/boot/lpm3.img
%endif
%endif
/boot/*.fd

%changelog
* Tue Sep  5 2023 Michal Suchanek <msuchanek@suse.com>
- Drop python2 dependency, python2 is obsolete.
* Mon Apr  3 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add ArmVExpress-FVP-AArch64
* Thu Jan 19 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to 202211:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable202211
- Update edk2-platforms to version 0.0~20230118T162833~201514e6
- Update edk2-non-osi to version 0.0~20230118T154213~bc0b6bf
- Update openssl to 1.1.1s
- Update openssl.keyring
- Add patch to fix build for Hikey/Hikey960:
  * edk2-platforms-fix-Hikeys.patch
- Drop upstream patch:
  * edk2-7d74ea14.patch
* Thu Nov 10 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patch to fix build:
  * edk2-7d74ea14.patch
* Thu Oct 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to 202208:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable202208
* Thu May 19 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to stable202205-rc1 to fix build with GCC12:
  * changelog: not available for *-rcX
  * changelog from skipped 202108:
    https://github.com/tianocore/edk2/releases/tag/edk2-stable202108
  * changelog from skipped 202111:
    https://github.com/tianocore/edk2/releases/tag/edk2-stable202111
  * changelog from skipped 202202:
    https://github.com/tianocore/edk2/releases/tag/edk2-stable202202
- Update edk2-platforms to version 0.0~20220516T160923~03d1c51272
- Update edk2-non-osi to version 0.0~20220407T181805~6996a45
- Update openssl to 1.1.1n
* Thu Jun  3 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to 202105:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable202105
    Fix CVE-2021-23841 and CVE-2021-23840
- Fix build with GCC11
* Tue Jan 26 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build with rpm 4.16
* Thu Jan  7 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix name when %%{platform} is null to have 'edk2' instead of 'edk2-'
* Thu Dec 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add SbsaQemu and Overdrive1000Board
* Thu Dec 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to 202011:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable202011
    Fix CVE-2019-14584
  * changelog of 202008 (skipped):
    https://github.com/tianocore/edk2/releases/tag/edk2-stable202008
    Fix CVE-2019-11098
  * changelog of 202005 (skipped):
    https://github.com/tianocore/edk2/releases/tag/edk2-stable202005
- Update edk2-platforms to version 0.0~20201209T010944~8f088a1224
- Update edk2-non-osi to version 0.0~20201209T013638~659382a
- Update openssl to 1.1.1g
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add RPi4 platform
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to version 202002:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable202002
  * changelog of 201911 (skipped):
    https://github.com/tianocore/edk2/releases/tag/edk2-stable201911
- Update edk2-non-osi to version 0.0~20200421T141136~96ec764
- Update edk2-platforms to version 0.0~20200421T131746~5a60c2de3c
* Thu Oct 24 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to version 201908:
  * changelog: https://github.com/tianocore/edk2/releases/tag/edk2-stable201908
- Update edk2-non-osi to version 0.0~20191021T153136~243e55f
- Update edk2-platforms to version 0.0~20191021T153232~03f36b8fcf
* Thu Jun 27 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2-non-osi to version 0.0~20190610T165749~eb114ec
- Update edk2-platforms to version 0.0~20190626T215631~1710027938
* Fri Jun  7 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to version 201905
- Update edk2-platforms to version 0.0~20190604T211045~1098e7ec3e
* Tue May 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch to _multibuild
* Tue May 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add Armada80x0McBin platform
* Mon May 13 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update edk2 to version 201903
- Update edk2-platforms to version 0.0~20190513T092206~ffac728623
- Update edk2-non-osi to version 0.0~20190423T233527~596043f
- Remove upstreamed patches:
  * edk2-cve-2018-12181-1.patch
  * edk2-cve-2018-12181-2.patch
- Add RPi3 platform
- Build in DEBUG mode by default
* Fri Mar  8 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patches to fix boo#1128503 (CVE 2018-12181):
  * edk2-cve-2018-12181-1.patch
  * edk2-cve-2018-12181-2.patch
* Mon Nov 26 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch to upstream edk2 release
- Use a template file to add more platforms easily
- Remove all patches:
  * gcc7.diff
  * edk2_genvtf_gcc8.patch
  * edk2_genvtf_gcc8.diff
  * ovmf-pie.patch
* Sun Jun 24 2018 afaerber@suse.de
- Revert to gcc7
  gcc7.diff
* Tue Jun 12 2018 afaerber@suse.de
- Try to fix gcc8 build
  edk2_genvtf_gcc8.patch
  edk2_genvtf_gcc8.diff
* Thu May 31 2018 afaerber@suse.de
- Update sources
* Thu Feb  8 2018 afaerber@suse.de
- Update sources
  * Drop OpenPlatformPkg_uart_fifo.patch (upstream)
* Wed Feb  7 2018 afaerber@suse.de
- Build HiKey, too
- Fix arrow keys (b9o#659)
  OpenPlatformPkg_uart_fifo.patch
* Sun Jan  7 2018 afaerber@suse.de
- Update to edk2 2.5 + OpenPlatformPkg 1.3.4
* Mon Dec 26 2016 afaerber@suse.de
- Initial
